pub enum AiHeartbeatData {
Variant0 {
backend: AiHeartbeatDataVariant0Backend,
region: String,
status: AiHeartbeatStatus,
},
Variant1 {
backend: AiHeartbeatDataVariant1Backend,
location: String,
project: String,
status: AiHeartbeatStatus,
},
Variant2 {
account_name: String,
backend: AiHeartbeatDataVariant2Backend,
endpoint: Option<String>,
location: Option<String>,
resource_group: Option<String>,
status: AiHeartbeatStatus,
},
Variant3 {
backend: AiHeartbeatDataVariant3Backend,
provider: String,
status: AiHeartbeatStatus,
},
}Expand description
AiHeartbeatData
JSON schema
{
"oneOf": [
{
"allOf": [
{
"$ref": "#/components/schemas/AwsBedrockAiHeartbeatData"
},
{
"type": "object",
"required": [
"backend"
],
"properties": {
"backend": {
"type": "string",
"enum": [
"awsBedrock"
]
}
}
}
]
},
{
"allOf": [
{
"$ref": "#/components/schemas/GcpVertexAiHeartbeatData"
},
{
"type": "object",
"required": [
"backend"
],
"properties": {
"backend": {
"type": "string",
"enum": [
"gcpVertex"
]
}
}
}
]
},
{
"allOf": [
{
"$ref": "#/components/schemas/AzureFoundryAiHeartbeatData"
},
{
"type": "object",
"required": [
"backend"
],
"properties": {
"backend": {
"type": "string",
"enum": [
"azureFoundry"
]
}
}
}
]
},
{
"allOf": [
{
"$ref": "#/components/schemas/ExternalAiHeartbeatData"
},
{
"type": "object",
"required": [
"backend"
],
"properties": {
"backend": {
"type": "string",
"enum": [
"external"
]
}
}
}
]
}
]
}Variants
Variant0
Variant1
Variant2
Variant3
Fields

backend: AiHeartbeatDataVariant3Backend
provider: StringThe BYO-key provider serving this binding (e.g. “openai”). Used on the Local platform, where the app brings its own provider key instead of an ambient cloud.

status: AiHeartbeatStatusTrait Implementations
Sourceimpl Clone for AiHeartbeatData
impl Clone for AiHeartbeatData
Sourcefn clone(&self) -> AiHeartbeatData
fn clone(&self) -> AiHeartbeatData
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AiHeartbeatData
impl Debug for AiHeartbeatData
Sourceimpl<'de> Deserialize<'de> for AiHeartbeatData
impl<'de> Deserialize<'de> for AiHeartbeatData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&AiHeartbeatData> for AiHeartbeatData
impl From<&AiHeartbeatData> for AiHeartbeatData
Sourcefn from(value: &AiHeartbeatData) -> Self
fn from(value: &AiHeartbeatData) -> Self
Converts to this type from the input type.
Sourceimpl From<AiHeartbeatData> for ResourceHeartbeatData
impl From<AiHeartbeatData> for ResourceHeartbeatData
Sourcefn from(value: AiHeartbeatData) -> Self
fn from(value: AiHeartbeatData) -> Self
Converts to this type from the input type.