pub enum KubernetesCertificateMode {
Variant0 {
mode: KubernetesCertificateModeVariant0Mode,
region: Option<String>,
tags: HashMap<String, String>,
},
Variant1 {
certificate_arn: String,
mode: KubernetesCertificateModeVariant1Mode,
},
Variant2 {
mode: KubernetesCertificateModeVariant2Mode,
secret_name_template: String,
},
Variant3 {
mode: KubernetesCertificateModeVariant3Mode,
namespace: Option<String>,
secret_name: String,
},
Variant4 {
mode: KubernetesCertificateModeVariant4Mode,
},
}Expand description
Certificate publication or reference mode for Kubernetes public endpoints.
JSON schema
{
"description": "Certificate publication or reference mode for Kubernetes public endpoints.",
"oneOf": [
{
"description": "Platform-managed cert imported into AWS ACM by the runtime.",
"type": "object",
"required": [
"mode"
],
"properties": {
"mode": {
"type": "string",
"enum": [
"managedAcmImport"
]
},
"region": {
"description": "ACM region. Defaults to the deployment region when omitted.",
"type": [
"string",
"null"
]
},
"tags": {
"description": "Tags applied to runtime-imported ACM certificates.",
"type": "object",
"additionalProperties": {
"type": "string"
}
}
}
},
{
"description": "Customer-provided AWS ACM certificate ARN.",
"type": "object",
"required": [
"certificateArn",
"mode"
],
"properties": {
"certificateArn": {
"description": "Existing ACM certificate ARN.",
"type": "string"
},
"mode": {
"type": "string",
"enum": [
"awsAcmArn"
]
}
}
},
{
"description": "Platform-managed cert written to a Kubernetes TLS Secret.",
"type": "object",
"required": [
"mode",
"secretNameTemplate"
],
"properties": {
"mode": {
"type": "string",
"enum": [
"managedTlsSecret"
]
},
"secretNameTemplate": {
"description": "Secret name template. Runtime may substitute resource/deployment tokens.",
"type": "string"
}
}
},
{
"description": "Customer-provided Kubernetes TLS Secret.",
"allOf": [
{
"$ref": "#/components/schemas/KubernetesTlsSecretRef"
},
{
"type": "object",
"required": [
"mode"
],
"properties": {
"mode": {
"type": "string",
"enum": [
"tlsSecretRef"
]
}
}
}
]
},
{
"description": "No TLS certificate should be configured by Alien.",
"type": "object",
"required": [
"mode"
],
"properties": {
"mode": {
"type": "string",
"enum": [
"none"
]
}
}
}
]
}Variants
Variant0
Fields
Tags applied to runtime-imported ACM certificates.
Variant1
Fields
Variant2
Fields
Variant3
Fields
Variant4
Fields