KubernetesRouteProviderOptions

Enum KubernetesRouteProviderOptions 

pub enum KubernetesRouteProviderOptions {
    AwsAlb {
        ip_address_type: Option<String>,
        scheme: String,
        subnet_ids: Vec<String>,
        target_type: String,
    },
    GkeGateway {
        static_address_name: Option<String>,
    },
    AzureApplicationGatewayForContainers {
        alb_name: Option<String>,
        alb_namespace: Option<String>,
        frontend: String,
    },
}
Provider-specific route options required by supported managed profiles.

JSON schema
{
 "description": "Provider-specific route options required by supported managed profiles.",
 "oneOf": [
   {
     "description": "AWS ALB route options for EKS.",
     "type": "object",
     "required": [
       "provider",
       "scheme",
       "targetType"
     ],
     "properties": {
       "ipAddressType": {
         "description": "Optional ALB IP address type, such as `dualstack`.",
         "type": [
           "string",
           "null"
         ]
       },
       "provider": {
         "type": "string",
         "enum": [
           "awsAlb"
         ]
       },
       "scheme": {
         "description": "Internet-facing or internal ALB scheme.",
         "type": "string"
       },
       "subnetIds": {
         "description": "Explicit subnet IDs when the profile cannot rely on controller discovery.",
         "type": "array",
         "items": {
           "type": "string"
         }
       },
       "targetType": {
         "description": "ALB target type, usually `ip`.",
         "type": "string"
       }
     }
   },
   {
     "description": "GKE Gateway route options.",
     "type": "object",
     "required": [
       "provider"
     ],
     "properties": {
       "provider": {
         "type": "string",
         "enum": [
           "gkeGateway"
         ]
       },
       "staticAddressName": {
         "description": "Optional static address name for the Gateway frontend.",
         "type": [
           "string",
           "null"
         ]
       }
     }
   },
   {
     "description": "Azure Application Gateway for Containers route options.",
     "type": "object",
     "required": [
       "frontend",
       "provider"
     ],
     "properties": {
       "albName": {
         "description": "Optional ALB name when using BYO Application Gateway resources.",
         "type": [
           "string",
           "null"
         ]
       },
       "albNamespace": {
         "description": "Optional ALB namespace when using BYO Application Gateway resources.",
         "type": [
           "string",
           "null"
         ]
       },
       "frontend": {
         "description": "Public or internal frontend exposure.",
         "type": "string"
       },
       "provider": {
         "type": "string",
         "enum": [
           "azureApplicationGatewayForContainers"
         ]
       }
     }
   }
 ]
}

Variants



AwsAlb

AWS ALB route options for EKS.

Fields

ip_address_type: Option<String>

Optional ALB IP address type, such as dualstack.

scheme: String

Internet-facing or internal ALB scheme.

subnet_ids: Vec<String>

Explicit subnet IDs when the profile cannot rely on controller discovery.

target_type: String

ALB target type, usually ip.



GkeGateway

GKE Gateway route options.

Fields

static_address_name: Option<String>

Optional static address name for the Gateway frontend.



AzureApplicationGatewayForContainers

Azure Application Gateway for Containers route options.

Fields

alb_name: Option<String>

Optional ALB name when using BYO Application Gateway resources.

alb_namespace: Option<String>

Optional ALB namespace when using BYO Application Gateway resources.

frontend: String

Public or internal frontend exposure.