pub enum OperatorCapabilityState {
Granted,
Denied,
Unavailable,
}Expand description
State of an Operator capability as observed inside the environment.
JSON schema
{
"description": "State of an Operator capability as observed inside the environment.",
"type": "string",
"enum": [
"granted",
"denied",
"unavailable"
]
}Variants