pub enum RemoteAzureCredentials {
AccessToken(String),
}Expand description
The only Azure credential form remote binding resolution can return.
JSON schema
{
"description": "The only Azure credential form remote binding resolution can return.",
"oneOf": [
{
"description": "OAuth bearer token for `https://storage.azure.com/.default`.",
"type": "object",
"required": [
"token",
"type"
],
"properties": {
"token": {
"type": "string"
},
"type": {
"type": "string",
"enum": [
"accessToken"
]
}
}
}
]
}Variants