pub enum ResolveBindingResponse {
S3 {
binding: RemoteS3StorageBinding,
client_config: RemoteAwsClientConfig,
expires_at: String,
},
Blob {
binding: RemoteBlobStorageBinding,
client_config: RemoteAzureClientConfig,
expires_at: String,
},
Gcs {
binding: RemoteGcsStorageBinding,
client_config: RemoteGcpClientConfig,
expires_at: String,
},
}Expand description
One approved remote Storage binding paired with credentials for the same provider. The discriminant makes cross-provider combinations impossible.
JSON schema
{
"description": "One approved remote Storage binding paired with credentials for the same\nprovider. The discriminant makes cross-provider combinations impossible.",
"oneOf": [
{
"description": "AWS S3 and an AWS session.",
"type": "object",
"required": [
"binding",
"clientConfig",
"expiresAt",
"service"
],
"properties": {
"binding": {
"$ref": "#/components/schemas/RemoteS3StorageBinding"
},
"clientConfig": {
"$ref": "#/components/schemas/RemoteAwsClientConfig"
},
"expiresAt": {
"type": "string"
},
"service": {
"type": "string",
"enum": [
"s3"
]
}
}
},
{
"description": "Azure Blob Storage and a storage-audience access token.",
"type": "object",
"required": [
"binding",
"clientConfig",
"expiresAt",
"service"
],
"properties": {
"binding": {
"$ref": "#/components/schemas/RemoteBlobStorageBinding"
},
"clientConfig": {
"$ref": "#/components/schemas/RemoteAzureClientConfig"
},
"expiresAt": {
"type": "string"
},
"service": {
"type": "string",
"enum": [
"blob"
]
}
}
},
{
"description": "Google Cloud Storage and a Remote Bindings identity access token.",
"type": "object",
"required": [
"binding",
"clientConfig",
"expiresAt",
"service"
],
"properties": {
"binding": {
"$ref": "#/components/schemas/RemoteGcsStorageBinding"
},
"clientConfig": {
"$ref": "#/components/schemas/RemoteGcpClientConfig"
},
"expiresAt": {
"type": "string"
},
"service": {
"type": "string",
"enum": [
"gcs"
]
}
}
}
]
}Variants
S3
AWS S3 and an AWS session.
Blob
Azure Blob Storage and a storage-audience access token.
Gcs
Google Cloud Storage and a Remote Bindings identity access token.