pub enum ResourceLifecycle {
Frozen,
Live,
LiveOnSetup,
}Expand description
Describes the lifecycle of a resource within a stack, determining how it’s managed and deployed.
JSON schema
{
"description": "Describes the lifecycle of a resource within a stack, determining how it's managed and deployed.",
"type": "string",
"enum": [
"frozen",
"live",
"live-on-setup"
]
}Variants