pub struct AgentSyncRequest {
pub current_state: Option<Value>,
pub deployment_id: String,
}Expand description
AgentSyncRequest
JSON schema
{
"type": "object",
"required": [
"deploymentId"
],
"properties": {
"currentState": {
"description": "Current deployment state as reported by the agent.\nWhen present, the manager updates the deployment record to reflect\nthe agent's progress (status, stack_state, etc.)."
},
"deploymentId": {
"type": "string"
}
}
}Fields
current_state: Option<Value>Current deployment state as reported by the agent. When present, the manager updates the deployment record to reflect the agent’s progress (status, stack_state, etc.).
deployment_id: StringImplementations
Sourceimpl AgentSyncRequest
impl AgentSyncRequest
pub fn builder() -> AgentSyncRequest