pub struct AgentSyncResponse {
pub commands_url: Option<String>,
pub current_state: Option<Value>,
pub target: Option<Value>,
}Expand description
AgentSyncResponse
JSON schema
{
"type": "object",
"properties": {
"commandsUrl": {
"description": "Public URL for the commands API. Cloud-deployed workers use this\nto poll for pending commands instead of the agent's local sync URL.",
"type": [
"string",
"null"
]
},
"currentState": {
"description": "Authoritative deployment state from the manager.\n\nReturned when a pull deployment attaches with an empty local state while\nthe manager already has imported or previously reconciled state."
},
"target": {}
}
}Fields
commands_url: Option<String>Public URL for the commands API. Cloud-deployed workers use this to poll for pending commands instead of the agent’s local sync URL.
current_state: Option<Value>Authoritative deployment state from the manager.
Returned when a pull deployment attaches with an empty local state while the manager already has imported or previously reconciled state.
target: Option<Value>Implementations
Sourceimpl AgentSyncResponse
impl AgentSyncResponse
pub fn builder() -> AgentSyncResponse