pub struct BaseResource {
pub id: String,
pub type_: ResourceType,
}Expand description
Resource that can hold any resource type in the Alien system. All resources share common ‘type’ and ‘id’ fields with additional type-specific properties.
JSON schema
{
"description": "Resource that can hold any resource type in the Alien system. All resources share common 'type' and 'id' fields with additional type-specific properties.",
"type": "object",
"required": [
"id",
"type"
],
"properties": {
"id": {
"description": "The unique identifier for this specific resource instance. Must contain only alphanumeric characters, hyphens, and underscores ([A-Za-z0-9-_]). Maximum 64 characters.",
"type": "string"
},
"type": {
"$ref": "#/components/schemas/ResourceType"
}
},
"additionalProperties": true
}Fields
id: StringThe unique identifier for this specific resource instance. Must contain only alphanumeric characters, hyphens, and underscores ([A-Za-z0-9-_]). Maximum 64 characters.
type_: ResourceTypeImplementations
Sourceimpl BaseResource
impl BaseResource
pub fn builder() -> BaseResource