pub struct BaseResourceOutputs {
pub type_: ResourceType,
}Expand description
Resource outputs that can hold output data for any resource type in the Alien system. All resource outputs share a common ‘type’ field with additional type-specific output properties.
JSON schema
{
"description": "Resource outputs that can hold output data for any resource type in the Alien system. All resource outputs share a common 'type' field with additional type-specific output properties.",
"type": "object",
"required": [
"type"
],
"properties": {
"type": {
"$ref": "#/components/schemas/ResourceType"
}
},
"additionalProperties": true
}Fields
type_: ResourceTypeImplementations
Sourceimpl BaseResourceOutputs
impl BaseResourceOutputs
pub fn builder() -> BaseResourceOutputs