pub struct CommandPayloadResponse {
pub command_id: String,
pub params: Option<BodySpec>,
pub response: Option<CommandResponse>,
}Expand description
Payload response containing params and response data from KV
JSON schema
{
"description": "Payload response containing params and response data from KV",
"type": "object",
"required": [
"commandId"
],
"properties": {
"commandId": {
"type": "string"
},
"params": {
"$ref": "#/components/schemas/BodySpec"
},
"response": {
"$ref": "#/components/schemas/CommandResponse"
}
}
}Fields
command_id: Stringparams: Option<BodySpec>response: Option<CommandResponse>Implementations
Sourceimpl CommandPayloadResponse
impl CommandPayloadResponse
pub fn builder() -> CommandPayloadResponse