pub struct FailureDomainSelection {
pub selected_failure_domains: Vec<String>,
pub spread: i32,
}Expand description
Failure-domain policy selected for a compute pool.
JSON schema
{
"description": "Failure-domain policy selected for a compute pool.",
"type": "object",
"required": [
"spread"
],
"properties": {
"selectedFailureDomains": {
"description": "Concrete provider domains selected during setup.\nEmpty delegates deterministic selection to the provider setup implementation.",
"type": "array",
"items": {
"type": "string"
}
},
"spread": {
"description": "Number of distinct failure domains across which new stateful replicas may be spread.",
"type": "integer",
"format": "int32",
"minimum": 0.0
}
}
}Fields
selected_failure_domains: Vec<String>Concrete provider domains selected during setup. Empty delegates deterministic selection to the provider setup implementation.
spread: i32Number of distinct failure domains across which new stateful replicas may be spread.
Implementations
Sourceimpl FailureDomainSelection
impl FailureDomainSelection
pub fn builder() -> FailureDomainSelection