pub struct GcpImpersonationConfig {
pub delegates: Option<Vec<String>>,
pub lifetime: Option<String>,
pub scopes: Vec<String>,
pub service_account_email: String,
pub target_project_id: Option<String>,
pub target_region: Option<String>,
}Expand description
Configuration for GCP service account impersonation
JSON schema
{
"description": "Configuration for GCP service account impersonation",
"type": "object",
"required": [
"scopes",
"serviceAccountEmail"
],
"properties": {
"delegates": {
"description": "Optional sequence of service accounts in a delegation chain",
"type": [
"array",
"null"
],
"items": {
"type": "string"
}
},
"lifetime": {
"description": "Optional desired lifetime duration of the access token (max 3600s)",
"type": [
"string",
"null"
]
},
"scopes": {
"description": "The OAuth 2.0 scopes that define the access token's permissions",
"type": "array",
"items": {
"type": "string"
}
},
"serviceAccountEmail": {
"description": "The email of the service account to impersonate",
"type": "string"
},
"targetProjectId": {
"description": "Optional target project ID override. When provided, the impersonated config\nuses this project ID instead of inheriting the caller's project.",
"type": [
"string",
"null"
]
},
"targetRegion": {
"description": "Optional target region override. When provided, the impersonated config\nuses this region instead of inheriting the caller's region.",
"type": [
"string",
"null"
]
}
},
"additionalProperties": false
}Fields
delegates: Option<Vec<String>>Optional sequence of service accounts in a delegation chain
lifetime: Option<String>Optional desired lifetime duration of the access token (max 3600s)
scopes: Vec<String>The OAuth 2.0 scopes that define the access token’s permissions
service_account_email: StringThe email of the service account to impersonate
target_project_id: Option<String>Optional target project ID override. When provided, the impersonated config uses this project ID instead of inheriting the caller’s project.
target_region: Option<String>Optional target region override. When provided, the impersonated config uses this region instead of inheriting the caller’s region.
Implementations
Sourceimpl GcpImpersonationConfig
impl GcpImpersonationConfig
pub fn builder() -> GcpImpersonationConfig