pub struct KubernetesSettings {
pub cluster: Option<KubernetesClusterSettings>,
pub exposure: Option<KubernetesExposureSettings>,
}Expand description
Kubernetes runtime substrate configuration.
This controls how setup chooses the cluster backing Platform::Kubernetes
deployments. When omitted, cloud-backed Kubernetes deployments default to a
managed cluster and generic/on-prem Kubernetes defaults to an external
cluster.
JSON schema
{
"description": "Kubernetes runtime substrate configuration.\n\nThis controls how setup chooses the cluster backing `Platform::Kubernetes`\ndeployments. When omitted, cloud-backed Kubernetes deployments default to a\nmanaged cluster and generic/on-prem Kubernetes defaults to an external\ncluster.",
"type": "object",
"properties": {
"cluster": {
"$ref": "#/components/schemas/KubernetesClusterSettings"
},
"exposure": {
"$ref": "#/components/schemas/KubernetesExposureSettings"
}
}
}Fields
cluster: Option<KubernetesClusterSettings>exposure: Option<KubernetesExposureSettings>Implementations
Sourceimpl KubernetesSettings
impl KubernetesSettings
pub fn builder() -> KubernetesSettings