pub struct ObservedInventoryBatch {
pub backend: HeartbeatBackend,
pub complete: bool,
pub controller_platform: Platform,
pub inventory_scope: String,
pub observed_at: DateTime<Utc>,
pub resources: Vec<ObservedResourceSample>,
pub source_kind: String,
}Expand description
ObservedInventoryBatch
JSON schema
{
"type": "object",
"required": [
"backend",
"complete",
"controllerPlatform",
"inventoryScope",
"observedAt",
"resources",
"sourceKind"
],
"properties": {
"backend": {
"$ref": "#/components/schemas/HeartbeatBackend"
},
"complete": {
"description": "Whether this batch is a complete replacement for the scope. Complete\nbatches tombstone previously observed rows in the same scope when they\nare absent from `resources`.",
"type": "boolean"
},
"controllerPlatform": {
"$ref": "#/components/schemas/Platform"
},
"inventoryScope": {
"description": "Stable scope for the provider list operation that produced this batch.",
"type": "string"
},
"observedAt": {
"description": "Time the inventory scope was observed.",
"type": "string",
"format": "date-time"
},
"resources": {
"type": "array",
"items": {
"$ref": "#/components/schemas/ObservedResourceSample"
}
},
"sourceKind": {
"description": "Writer/source for this inventory pass, such as `operator` or\n`manager-observer`.",
"type": "string"
}
}
}Fields
backend: HeartbeatBackendcomplete: boolWhether this batch is a complete replacement for the scope. Complete
batches tombstone previously observed rows in the same scope when they
are absent from resources.
controller_platform: Platforminventory_scope: StringStable scope for the provider list operation that produced this batch.
observed_at: DateTime<Utc>Time the inventory scope was observed.
resources: Vec<ObservedResourceSample>source_kind: StringWriter/source for this inventory pass, such as operator or
manager-observer.
Implementations
Sourceimpl ObservedInventoryBatch
impl ObservedInventoryBatch
pub fn builder() -> ObservedInventoryBatch