pub struct ObservedResourceSample {Show 20 fields
pub alien_resource_id: Option<String>,
pub attributes: HashMap<String, Value>,
pub collection_issues: Vec<HeartbeatCollectionIssue>,
pub counts: Option<ObservedCounts>,
pub deployment_id: Option<String>,
pub display_name: String,
pub health: ObservedHealth,
pub labels: HashMap<String, String>,
pub lifecycle: ProviderLifecycleState,
pub message: Option<String>,
pub namespace: Option<String>,
pub partial: bool,
pub provider_kind: String,
pub provider_stale: bool,
pub raw: Vec<RawHeartbeatSnippet>,
pub raw_identity: String,
pub region: Option<String>,
pub resource_type_hint: Option<ResourceType>,
pub scope: Option<String>,
pub version: Option<String>,
}Expand description
ObservedResourceSample
JSON schema
{
"type": "object",
"required": [
"displayName",
"health",
"lifecycle",
"partial",
"providerKind",
"providerStale",
"rawIdentity"
],
"properties": {
"alienResourceId": {
"type": [
"string",
"null"
]
},
"attributes": {
"type": "object",
"additionalProperties": {
"$ref": "#/components/schemas/Value"
}
},
"collectionIssues": {
"type": "array",
"items": {
"$ref": "#/components/schemas/HeartbeatCollectionIssue"
}
},
"counts": {
"$ref": "#/components/schemas/ObservedCounts"
},
"deploymentId": {
"type": [
"string",
"null"
]
},
"displayName": {
"type": "string"
},
"health": {
"$ref": "#/components/schemas/ObservedHealth"
},
"labels": {
"type": "object",
"additionalProperties": {
"type": "string"
}
},
"lifecycle": {
"$ref": "#/components/schemas/ProviderLifecycleState"
},
"message": {
"type": [
"string",
"null"
]
},
"namespace": {
"type": [
"string",
"null"
]
},
"partial": {
"type": "boolean"
},
"providerKind": {
"description": "Provider-native kind, such as `apps/v1/Deployment`,\n`AWS::S3::Bucket`, `storage.googleapis.com/Bucket`, or an Azure\nresource type.",
"type": "string"
},
"providerStale": {
"type": "boolean"
},
"raw": {
"type": "array",
"items": {
"$ref": "#/components/schemas/RawHeartbeatSnippet"
}
},
"rawIdentity": {
"description": "Provider-native stable identity: Kubernetes object identity, cloud ARN,\nGCP full resource name, Azure resource id, etc.",
"type": "string"
},
"region": {
"type": [
"string",
"null"
]
},
"resourceTypeHint": {
"$ref": "#/components/schemas/ResourceType"
},
"scope": {
"type": [
"string",
"null"
]
},
"version": {
"description": "Release/version identity observed from the provider resource, when available.",
"type": [
"string",
"null"
]
}
}
}Fields
alien_resource_id: Option<String>attributes: HashMap<String, Value>collection_issues: Vec<HeartbeatCollectionIssue>counts: Option<ObservedCounts>deployment_id: Option<String>display_name: Stringhealth: ObservedHealthlabels: HashMap<String, String>lifecycle: ProviderLifecycleStatemessage: Option<String>namespace: Option<String>partial: boolprovider_kind: StringProvider-native kind, such as apps/v1/Deployment,
AWS::S3::Bucket, storage.googleapis.com/Bucket, or an Azure
resource type.
provider_stale: boolraw: Vec<RawHeartbeatSnippet>raw_identity: StringProvider-native stable identity: Kubernetes object identity, cloud ARN, GCP full resource name, Azure resource id, etc.
region: Option<String>resource_type_hint: Option<ResourceType>scope: Option<String>version: Option<String>Release/version identity observed from the provider resource, when available.
Implementations
Sourceimpl ObservedResourceSample
impl ObservedResourceSample
pub fn builder() -> ObservedResourceSample