pub struct PermissionSet {
pub description: String,
pub id: String,
pub platforms: PlatformPermissions,
}Expand description
A permission set that can be applied across different cloud platforms
JSON schema
{
"description": "A permission set that can be applied across different cloud platforms",
"type": "object",
"required": [
"description",
"id",
"platforms"
],
"properties": {
"description": {
"description": "Human-readable description of what this permission set allows",
"type": "string"
},
"id": {
"description": "Unique identifier for the permission set (e.g., \"storage/data-read\")",
"type": "string"
},
"platforms": {
"description": "Platform-specific permission configurations",
"allOf": [
{
"$ref": "#/components/schemas/PlatformPermissions"
}
]
}
},
"additionalProperties": false
}Fields
description: StringHuman-readable description of what this permission set allows
id: StringUnique identifier for the permission set (e.g., “storage/data-read”)
platforms: PlatformPermissionsPlatform-specific permission configurations
Implementations
Sourceimpl PermissionSet
impl PermissionSet
pub fn builder() -> PermissionSet