pub struct PresignedRequest {
pub backend: PresignedRequestBackend,
pub expiration: DateTime<Utc>,
pub operation: PresignedOperation,
pub path: String,
}Expand description
A presigned request that can be serialized, stored, and executed later. Hides implementation details for different storage backends.
JSON schema
{
"description": "A presigned request that can be serialized, stored, and executed later.\nHides implementation details for different storage backends.",
"type": "object",
"required": [
"backend",
"expiration",
"operation",
"path"
],
"properties": {
"backend": {
"$ref": "#/components/schemas/PresignedRequestBackend"
},
"expiration": {
"description": "When this presigned request expires",
"type": "string",
"format": "date-time"
},
"operation": {
"$ref": "#/components/schemas/PresignedOperation"
},
"path": {
"description": "The path this request operates on",
"type": "string"
}
}
}Fields
backend: PresignedRequestBackendexpiration: DateTime<Utc>When this presigned request expires
operation: PresignedOperationpath: StringThe path this request operates on
Implementations
Sourceimpl PresignedRequest
impl PresignedRequest
pub fn builder() -> PresignedRequest