pub struct RemoteBlobStorageBinding {
pub account_name: String,
pub container_name: String,
}Expand description
Concrete Azure Blob Storage topology returned to remote clients.
JSON schema
{
"description": "Concrete Azure Blob Storage topology returned to remote clients.",
"type": "object",
"required": [
"accountName",
"containerName"
],
"properties": {
"accountName": {
"description": "Storage account containing the authorized container.",
"type": "string"
},
"containerName": {
"description": "Blob container authorized by the credential lease.",
"type": "string"
}
},
"additionalProperties": false
}Fields
account_name: StringStorage account containing the authorized container.
container_name: StringBlob container authorized by the credential lease.
Implementations
Sourceimpl RemoteBlobStorageBinding
impl RemoteBlobStorageBinding
pub fn builder() -> RemoteBlobStorageBinding