pub struct RemoteGcpClientConfig {
pub credentials: RemoteGcpCredentials,
pub project_id: String,
pub project_number: Option<String>,
pub region: String,
}Expand description
Response-safe GCP client configuration. Refreshable source credentials and service endpoint overrides cannot be represented by this type.
JSON schema
{
"description": "Response-safe GCP client configuration. Refreshable source credentials and\nservice endpoint overrides cannot be represented by this type.",
"type": "object",
"required": [
"credentials",
"projectId",
"region"
],
"properties": {
"credentials": {
"$ref": "#/components/schemas/RemoteGcpCredentials"
},
"projectId": {
"description": "GCP project containing the bucket.",
"type": "string"
},
"projectNumber": {
"description": "Numeric GCP project id, when known.",
"type": [
"string",
"null"
]
},
"region": {
"description": "GCP region configured for the deployment.",
"type": "string"
}
},
"additionalProperties": false
}Fields
credentials: RemoteGcpCredentialsproject_id: StringGCP project containing the bucket.
project_number: Option<String>Numeric GCP project id, when known.
region: StringGCP region configured for the deployment.
Implementations
Sourceimpl RemoteGcpClientConfig
impl RemoteGcpClientConfig
pub fn builder() -> RemoteGcpClientConfig