pub struct RemoteGcsStorageBinding {
pub bucket_name: String,
}Expand description
Concrete Google Cloud Storage topology returned to remote clients.
JSON schema
{
"description": "Concrete Google Cloud Storage topology returned to remote clients.",
"type": "object",
"required": [
"bucketName"
],
"properties": {
"bucketName": {
"description": "GCS bucket name authorized by the credential lease.",
"type": "string"
}
},
"additionalProperties": false
}Fields
bucket_name: StringGCS bucket name authorized by the credential lease.
Implementations
Sourceimpl RemoteGcsStorageBinding
impl RemoteGcsStorageBinding
pub fn builder() -> RemoteGcsStorageBinding