pub struct ResourceEntry {
pub config: BaseResource,
pub dependencies: Vec<ResourceRef>,
pub lifecycle: ResourceLifecycle,
pub remote_access: Option<bool>,
}Expand description
ResourceEntry
JSON schema
{
"type": "object",
"required": [
"config",
"dependencies",
"lifecycle"
],
"properties": {
"config": {
"description": "Resource configuration (can be any type of resource)",
"allOf": [
{
"$ref": "#/components/schemas/BaseResource"
}
]
},
"dependencies": {
"description": "Additional dependencies for this resource beyond those defined in the resource itself.\nThe total dependencies are: resource.get_dependencies() + this list",
"type": "array",
"items": {
"$ref": "#/components/schemas/ResourceRef"
}
},
"lifecycle": {
"description": "Lifecycle management configuration for this resource",
"allOf": [
{
"$ref": "#/components/schemas/ResourceLifecycle"
}
]
},
"remoteAccess": {
"description": "Enable remote bindings for this resource (BYOB use case).\nWhen true, binding params are synced to StackState's `remote_binding_params`.\nDefault: false (prevents sensitive data in synced state).",
"type": "boolean"
}
},
"additionalProperties": false
}Fields
config: BaseResourceResource configuration (can be any type of resource)
dependencies: Vec<ResourceRef>Additional dependencies for this resource beyond those defined in the resource itself. The total dependencies are: resource.get_dependencies() + this list
lifecycle: ResourceLifecycleLifecycle management configuration for this resource
remote_access: Option<bool>Enable remote bindings for this resource (BYOB use case).
When true, binding params are synced to StackState’s remote_binding_params.
Default: false (prevents sensitive data in synced state).
Implementations
Sourceimpl ResourceEntry
impl ResourceEntry
pub fn builder() -> ResourceEntry