pub struct ResponseHandling {
pub max_inline_bytes: i64,
pub storage_upload_request: PresignedRequest,
pub submit_response_url: String,
}Expand description
Response handling configuration for deployments
JSON schema
{
"description": "Response handling configuration for deployments",
"type": "object",
"required": [
"maxInlineBytes",
"storageUploadRequest",
"submitResponseUrl"
],
"properties": {
"maxInlineBytes": {
"description": "Maximum response body size that can be submitted inline",
"type": "integer",
"format": "int64",
"minimum": 0.0
},
"storageUploadRequest": {
"$ref": "#/components/schemas/PresignedRequest"
},
"submitResponseUrl": {
"description": "URL where deployments submit responses",
"type": "string"
}
}
}Fields
max_inline_bytes: i64Maximum response body size that can be submitted inline
storage_upload_request: PresignedRequestsubmit_response_url: StringURL where deployments submit responses
Implementations
Sourceimpl ResponseHandling
impl ResponseHandling
pub fn builder() -> ResponseHandling