pub struct StackImportResponse {
pub deployment_id: String,
pub deployment_token: Option<String>,
pub stack_settings: StackSettings,
pub stack_state: StackState,
}Expand description
Response body returned after a stack import.
JSON schema
{
"description": "Response body returned after a stack import.",
"type": "object",
"required": [
"deploymentId",
"stackSettings",
"stackState"
],
"properties": {
"deploymentId": {
"description": "Deployment created.",
"type": "string"
},
"deploymentToken": {
"description": "Deployment bearer token for the imported deployment, when available.",
"type": [
"string",
"null"
]
},
"stackSettings": {
"$ref": "#/components/schemas/StackSettings"
},
"stackState": {
"$ref": "#/components/schemas/StackState"
}
}
}Fields
deployment_id: StringDeployment created.
deployment_token: Option<String>Deployment bearer token for the imported deployment, when available.
stack_settings: StackSettingsstack_state: StackStateImplementations
Sourceimpl StackImportResponse
impl StackImportResponse
pub fn builder() -> StackImportResponse