Crate alien_manager_api

Crate alien_manager_api 

Alien Manager API

Auto-generated from OpenAPI spec using Progenitor. Provides a type-safe Rust client for the alien-manager API.

Usage

use alien_manager_api::Client;

let client = Client::new("http://localhost:8080");

// Create a deployment
let response = client
    .create_deployment()
    .body(&CreateDeploymentRequest {
        name: "my-deployment".into(),
        platform: Platform::Aws,
        ..Default::default()
    })
    .send()
    .await?;

Modules

builder
Types for composing operation parameters.
prelude
Items consumers will typically use such as the Client.
types
Types used as operation parameters and responses.

Structs

ByteStream
Untyped byte stream used for both success and error responses.
Client
Client for Alien Manager API
ResponseValue
Typed value returned by generated client methods.

Enums

Error
Error produced by generated client methods.

Traits

ClientInfo
Interface for which an implementation is generated for all clients.
SdkResultExt
Extension trait for converting manager SDK results to AlienError.

Functions

convert_sdk_error
Convert a progenitor SDK error to AlienError, preserving all details.