Module types

Module types 

Types used as operation parameters and responses.

Modules

builder
Types for composing complex structures.
error
Error types.

Structs

AcquireRequest
AcquireRequest
AcquireResponse
AcquireResponse
AcquiredDeploymentResponse
AcquiredDeploymentResponse
AgentSyncRequest
AgentSyncRequest
AgentSyncResponse
AgentSyncResponse
AlienError
Canonical error container that provides a structured way to represent errors with rich metadata including error codes, human-readable messages, context, and chaining capabilities for error propagation.
AlienErrorCode
A unique identifier for the type of error.
AlienErrorMessage
Human-readable error message.
ArtifactRegistryHeartbeatStatus
ArtifactRegistryHeartbeatStatus
AwsCodeBuildHeartbeatData
AwsCodeBuildHeartbeatData
AwsComputeClusterHeartbeatData
AwsComputeClusterHeartbeatData
AwsCustomCertificateConfig
AwsCustomCertificateConfig
AwsDaemonHeartbeatData
AwsDaemonHeartbeatData
AwsDynamoDbKeySchemaElement
AwsDynamoDbKeySchemaElement
AwsDynamoDbKvHeartbeatData
AwsDynamoDbKvHeartbeatData
AwsEcrArtifactRegistryHeartbeatData
AwsEcrArtifactRegistryHeartbeatData
AwsEcrRepositoryHeartbeatData
AwsEcrRepositoryHeartbeatData
AwsIamRoleServiceAccountHeartbeatData
AwsIamRoleServiceAccountHeartbeatData
AwsLambdaWorkerHeartbeatData
AwsLambdaWorkerHeartbeatData
AwsManagementConfig
AWS management configuration extracted from stack settings
AwsParameterStoreVaultHeartbeatData
AwsParameterStoreVaultHeartbeatData
AwsRemoteStackManagementHeartbeatData
AwsRemoteStackManagementHeartbeatData
AwsS3StorageHeartbeatData
AwsS3StorageHeartbeatData
AwsSqsQueueHeartbeatData
AwsSqsQueueHeartbeatData
AwsVpcNetworkHeartbeatData
AwsVpcNetworkHeartbeatData
AzureBlobStorageHeartbeatData
AzureBlobStorageHeartbeatData
AzureComputeClusterHeartbeatData
AzureComputeClusterHeartbeatData
AzureContainerAppsBuildHeartbeatData
AzureContainerAppsBuildHeartbeatData
AzureContainerAppsEnvironmentHeartbeatData
AzureContainerAppsEnvironmentHeartbeatData
AzureContainerAppsEnvironmentHeartbeatStatus
AzureContainerAppsEnvironmentHeartbeatStatus
AzureContainerAppsEnvironmentWorkloadProfile
AzureContainerAppsEnvironmentWorkloadProfile
AzureContainerAppsWorkerHeartbeatData
AzureContainerAppsWorkerHeartbeatData
AzureContainerRegistryHeartbeatData
AzureContainerRegistryHeartbeatData
AzureCustomCertificateConfig
AzureCustomCertificateConfig
AzureDaemonHeartbeatData
AzureDaemonHeartbeatData
AzureKeyVaultHeartbeatData
AzureKeyVaultHeartbeatData
AzureManagedIdentityServiceAccountHeartbeatData
AzureManagedIdentityServiceAccountHeartbeatData
AzureManagementConfig
Azure management configuration extracted from stack settings
AzureRemoteStackManagementHeartbeatData
AzureRemoteStackManagementHeartbeatData
AzureResourceGroupHeartbeatData
AzureResourceGroupHeartbeatData
AzureResourceGroupHeartbeatStatus
AzureResourceGroupHeartbeatStatus
AzureResourceProviderActivationHeartbeatData
AzureResourceProviderActivationHeartbeatData
AzureServiceBusNamespaceHeartbeatData
AzureServiceBusNamespaceHeartbeatData
AzureServiceBusQueueHeartbeatData
AzureServiceBusQueueHeartbeatData
AzureStorageAccountEndpoints
AzureStorageAccountEndpoints
AzureStorageAccountHeartbeatData
AzureStorageAccountHeartbeatData
AzureTableKvHeartbeatData
AzureTableKvHeartbeatData
AzureVnetNetworkHeartbeatData
AzureVnetNetworkHeartbeatData
BaseResource
Resource that can hold any resource type in the Alien system. All resources share common ‘type’ and ‘id’ fields with additional type-specific properties.
BaseResourceOutputs
Resource outputs that can hold output data for any resource type in the Alien system. All resource outputs share a common ‘type’ field with additional type-specific output properties.
BuildHeartbeatStatus
BuildHeartbeatStatus
CommandPayloadResponse
Payload response containing params and response data from KV
CommandStatusResponse
Response to status queries
CommandsInfo
CommandsInfo
ComputeCapacityBlocker
ComputeCapacityBlocker
ComputeCapacityGroupStatus
ComputeCapacityGroupStatus
ComputeCapacityRecommendation
ComputeCapacityRecommendation
ComputeClusterHeartbeatStatus
ComputeClusterHeartbeatStatus
CreateCommandRequest
Request to create a new command
CreateCommandResponse
Response to command creation
CreateDeploymentGroupRequest
CreateDeploymentGroupRequest
CreateDeploymentRequest
CreateDeploymentRequest
CreateDeploymentResponse
CreateDeploymentResponse
CreateReleaseRequest
CreateReleaseRequest
CreateTokenResponse
CreateTokenResponse
CustomCertificateConfig
Platform-specific certificate references for custom domains.
CustomDomainConfig
Custom domain configuration for a single resource.
DeleteDeploymentRequest
DeleteDeploymentRequest
DeploymentGroupMinimal
DeploymentGroupMinimal
DeploymentGroupResponse
DeploymentGroupResponse
DeploymentInfoResponse
DeploymentInfoResponse
DeploymentResponse
DeploymentResponse
DomainSettings
Domain configuration for the stack.
Envelope
Commands envelope sent to deployments
EnvironmentVariable
Environment variable for deployment
ErrorResponse
Error response wrapper for API endpoints
GcpArtifactRegistryHeartbeatData
GcpArtifactRegistryHeartbeatData
GcpCloudBuildHeartbeatData
GcpCloudBuildHeartbeatData
GcpCloudRunWorkerHeartbeatData
GcpCloudRunWorkerHeartbeatData
GcpCloudStorageHeartbeatData
GcpCloudStorageHeartbeatData
GcpComputeClusterHeartbeatData
GcpComputeClusterHeartbeatData
GcpCustomCertificateConfig
GcpCustomCertificateConfig
GcpDaemonHeartbeatData
GcpDaemonHeartbeatData
GcpFirestoreKvHeartbeatData
GcpFirestoreKvHeartbeatData
GcpManagementConfig
GCP management configuration extracted from stack settings
GcpPubSubQueueHeartbeatData
GcpPubSubQueueHeartbeatData
GcpRemoteStackManagementHeartbeatData
GcpRemoteStackManagementHeartbeatData
GcpSecretManagerVaultHeartbeatData
GcpSecretManagerVaultHeartbeatData
GcpServiceAccountHeartbeatData
GcpServiceAccountHeartbeatData
GcpServiceUsageActivationHeartbeatData
GcpServiceUsageActivationHeartbeatData
GcpVpcNetworkHeartbeatData
GcpVpcNetworkHeartbeatData
GitMetadata
GitMetadata
GitMetadataResponse
GitMetadataResponse
HealthResponse
HealthResponse
HeartbeatCollectionIssue
HeartbeatCollectionIssue
HorizonContainerHeartbeatData
HorizonContainerHeartbeatData
ImportedResource
One resolved resource import payload.
InitializeRequest
InitializeRequest
InitializeResponse
InitializeResponse
KubernetesBuildHeartbeatData
KubernetesBuildHeartbeatData
KubernetesCloudReference
Optional provider-specific identity for a cloud-backed Kubernetes cluster.
KubernetesClusterHeartbeatData
KubernetesClusterHeartbeatData
KubernetesClusterNodeStatus
KubernetesClusterNodeStatus
KubernetesClusterSettings
Kubernetes cluster setup settings.
KubernetesContainerHeartbeatData
KubernetesContainerHeartbeatData
KubernetesCustomCertificateConfig
KubernetesCustomCertificateConfig
KubernetesDaemonHeartbeatData
KubernetesDaemonHeartbeatData
KubernetesEventInvolvedObject
KubernetesEventInvolvedObject
KubernetesEventSnapshot
KubernetesEventSnapshot
KubernetesEventSource
KubernetesEventSource
KubernetesGatewayRouteProfile
Shared Gateway API route profile values.
KubernetesIngressRouteProfile
Shared Ingress route profile values.
KubernetesNodeConditionStatus
KubernetesNodeConditionStatus
KubernetesNodeResources
KubernetesNodeResources
KubernetesNodeUsage
KubernetesNodeUsage
KubernetesOwnerReference
KubernetesOwnerReference
KubernetesPodRuntimeUnitStatus
KubernetesPodRuntimeUnitStatus
KubernetesSecretVaultHeartbeatData
KubernetesSecretVaultHeartbeatData
KubernetesSettings
Kubernetes runtime substrate configuration.
KubernetesTlsSecretRef
Namespace-scoped Kubernetes TLS Secret reference.
KubernetesWorkerHeartbeatData
KubernetesWorkerHeartbeatData
KubernetesWorkloadCondition
KubernetesWorkloadCondition
KubernetesWorkloadStatus
KubernetesWorkloadStatus
KvHeartbeatStatus
KvHeartbeatStatus
LeaseInfo
Lease information
LeaseRequest
Request for acquiring leases
LeaseResponse
Response to lease acquisition
ListDeploymentGroupsResponse
ListDeploymentGroupsResponse
ListDeploymentsResponse
ListDeploymentsResponse
ListReleasesResponse
ListReleasesResponse
LocalArtifactRegistryHeartbeatData
LocalArtifactRegistryHeartbeatData
LocalComputeClusterHeartbeatData
LocalComputeClusterHeartbeatData
LocalContainerHeartbeatData
LocalContainerHeartbeatData
LocalDaemonHeartbeatData
LocalDaemonHeartbeatData
LocalKvHeartbeatData
LocalKvHeartbeatData
LocalQueueHeartbeatData
LocalQueueHeartbeatData
LocalRuntimeEventSnapshot
LocalRuntimeEventSnapshot
LocalRuntimeEventSubject
LocalRuntimeEventSubject
LocalRuntimeUnitStatus
LocalRuntimeUnitStatus
LocalServiceAccountHeartbeatData
LocalServiceAccountHeartbeatData
LocalStorageHeartbeatData
LocalStorageHeartbeatData
LocalVaultHeartbeatData
LocalVaultHeartbeatData
LocalWorkerHeartbeatData
LocalWorkerHeartbeatData
ManagedRuntimeEventInvolvedObject
ManagedRuntimeEventInvolvedObject
ManagedRuntimeEventSnapshot
ManagedRuntimeEventSnapshot
ManagedRuntimeEventSource
ManagedRuntimeEventSource
ManagedRuntimeUnitStatus
ManagedRuntimeUnitStatus
MetricSample
MetricSample
NetworkHeartbeatStatus
NetworkHeartbeatStatus
ObservedCounts
ObservedCounts
PresignedRequest
A presigned request that can be serialized, stored, and executed later. Hides implementation details for different storage backends.
ProviderFleetStatus
ProviderFleetStatus
QueueHeartbeatStatus
QueueHeartbeatStatus
RawHeartbeatSnippet
RawHeartbeatSnippet
ReconcileRequest
ReconcileRequest
ReconcileResponse
ReconcileResponse
ReleaseRequest
ReleaseRequest
ReleaseResponse
ReleaseResponse
RemoteStackManagementHeartbeatStatus
RemoteStackManagementHeartbeatStatus
ResolveCredentialsRequest
ResolveCredentialsRequest
ResolveCredentialsResponse
ResolveCredentialsResponse
ResourceEntry
ResourceEntry
ResourceHeartbeat
ResourceHeartbeat
ResourceRef
New ResourceRef that works with any resource type. This can eventually replace the enum-based ResourceRef for full extensibility.
ResourceType
Resource type identifier that determines the specific kind of resource. This field is used for polymorphic deserialization and resource-specific behavior.
ResponseHandling
Response handling configuration for deployments
ScopeInfo
ScopeInfo
ServiceAccountHeartbeatStatus
ServiceAccountHeartbeatStatus
ServiceActivationHeartbeatStatus
ServiceActivationHeartbeatStatus
StackByPlatform
The release API accepts stacks keyed by platform. Only one platform stack needs to be present.
StackImportRequest
Request body for manager-side stack import.
StackImportResponse
Response body returned after a stack import.
StackResourceState
Represents the state of a single resource within the stack for a specific platform.
StackSettings
User-customizable deployment settings specified at deploy time.
StackState
Represents the collective state of all resources in a stack, including platform and pending actions.
StorageHeartbeatStatus
StorageHeartbeatStatus
StorageUpload
Storage upload information
StorePayloadRequest
Request to store payload data directly in KV by command_id.
SubmitResponseRequest
Request to submit a command response (from deployment)
UploadCompleteRequest
Request to mark upload as complete
UploadCompleteResponse
Response to upload completion
Value
Value
VaultHeartbeatStatus
VaultHeartbeatStatus
WhoamiResponse
WhoamiResponse
WorkloadHeartbeatStatus
WorkloadHeartbeatStatus
WorkloadReplicaStatus
WorkloadReplicaStatus

Enums

ArtifactRegistryHeartbeatData
ArtifactRegistryHeartbeatData
ArtifactRegistryHeartbeatDataVariant0Backend
ArtifactRegistryHeartbeatDataVariant0Backend
ArtifactRegistryHeartbeatDataVariant1Backend
ArtifactRegistryHeartbeatDataVariant1Backend
ArtifactRegistryHeartbeatDataVariant2Backend
ArtifactRegistryHeartbeatDataVariant2Backend
ArtifactRegistryHeartbeatDataVariant3Backend
ArtifactRegistryHeartbeatDataVariant3Backend
BodySpec
Body specification supporting inline and storage modes
BuildHeartbeatData
BuildHeartbeatData
BuildHeartbeatDataVariant0Backend
BuildHeartbeatDataVariant0Backend
BuildHeartbeatDataVariant1Backend
BuildHeartbeatDataVariant1Backend
BuildHeartbeatDataVariant2Backend
BuildHeartbeatDataVariant2Backend
BuildHeartbeatDataVariant3Backend
BuildHeartbeatDataVariant3Backend
CommandResponse
Command response from deployment
CommandState
Command states in the Commands protocol lifecycle
ComputeCapacityBlockerCategory
ComputeCapacityBlockerCategory
ComputeClusterHeartbeatData
ComputeClusterHeartbeatData
ComputeClusterHeartbeatDataVariant0Backend
ComputeClusterHeartbeatDataVariant0Backend
ComputeClusterHeartbeatDataVariant1Backend
ComputeClusterHeartbeatDataVariant1Backend
ComputeClusterHeartbeatDataVariant2Backend
ComputeClusterHeartbeatDataVariant2Backend
ComputeClusterHeartbeatDataVariant3Backend
ComputeClusterHeartbeatDataVariant3Backend
ContainerHeartbeatData
ContainerHeartbeatData
ContainerHeartbeatDataVariant0Backend
ContainerHeartbeatDataVariant0Backend
ContainerHeartbeatDataVariant1Backend
ContainerHeartbeatDataVariant1Backend
ContainerHeartbeatDataVariant2Backend
ContainerHeartbeatDataVariant2Backend
DaemonHeartbeatData
DaemonHeartbeatData
DaemonHeartbeatDataVariant0Backend
DaemonHeartbeatDataVariant0Backend
DaemonHeartbeatDataVariant1Backend
DaemonHeartbeatDataVariant1Backend
DaemonHeartbeatDataVariant2Backend
DaemonHeartbeatDataVariant2Backend
DaemonHeartbeatDataVariant3Backend
DaemonHeartbeatDataVariant3Backend
DaemonHeartbeatDataVariant4Backend
DaemonHeartbeatDataVariant4Backend
DeleteDeploymentAction
DeleteDeploymentAction
DeploymentModel
Deployment model: how updates are delivered to the remote environment.
EnvironmentVariableType
Type of environment variable
HeartbeatBackend
HeartbeatBackend
HeartbeatCollectionIssueReason
HeartbeatCollectionIssueReason
HeartbeatIssueSeverity
HeartbeatIssueSeverity
HeartbeatsMode
How heartbeat health checks are handled.
HorizonWorkloadSchedulingMode
HorizonWorkloadSchedulingMode
ImportSourceKind
Package source that produced an import request. Observability label only — the manager does not branch on this value, and any new deployment pathway can omit it without affecting import behavior.
KubernetesCertificateMode
Certificate publication or reference mode for Kubernetes public endpoints.
KubernetesCertificateModeVariant0Mode
KubernetesCertificateModeVariant0Mode
KubernetesCertificateModeVariant1Mode
KubernetesCertificateModeVariant1Mode
KubernetesCertificateModeVariant2Mode
KubernetesCertificateModeVariant2Mode
KubernetesCertificateModeVariant3Mode
KubernetesCertificateModeVariant3Mode
KubernetesCertificateModeVariant4Mode
KubernetesCertificateModeVariant4Mode
KubernetesClusterOwnership
Ownership model for the Kubernetes cluster.
KubernetesExposureSettings
Kubernetes public HTTPS exposure mode.
KubernetesRouteProfile
Kubernetes route API selected for public endpoints.
KubernetesRouteProfileVariant0RouteApi
KubernetesRouteProfileVariant0RouteApi
KubernetesRouteProfileVariant1RouteApi
KubernetesRouteProfileVariant1RouteApi
KubernetesRouteProviderOptions
Provider-specific route options required by supported managed profiles.
KubernetesWorkloadKind
KubernetesWorkloadKind
KvHeartbeatData
KvHeartbeatData
KvHeartbeatDataVariant0Backend
KvHeartbeatDataVariant0Backend
KvHeartbeatDataVariant1Backend
KvHeartbeatDataVariant1Backend
KvHeartbeatDataVariant2Backend
KvHeartbeatDataVariant2Backend
KvHeartbeatDataVariant3Backend
KvHeartbeatDataVariant3Backend
LocalOperation
Local filesystem operations
LocalRuntimeUnitKind
LocalRuntimeUnitKind
ManagementConfig
Management configuration for different cloud platforms.
ManagementConfigVariant0Platform
ManagementConfigVariant0Platform
ManagementConfigVariant1Platform
ManagementConfigVariant1Platform
ManagementConfigVariant2Platform
ManagementConfigVariant2Platform
ManagementConfigVariant3Platform
ManagementConfigVariant3Platform
MetricUnit
MetricUnit
NetworkHeartbeatData
NetworkHeartbeatData
NetworkHeartbeatDataVariant0Backend
NetworkHeartbeatDataVariant0Backend
NetworkHeartbeatDataVariant1Backend
NetworkHeartbeatDataVariant1Backend
NetworkHeartbeatDataVariant2Backend
NetworkHeartbeatDataVariant2Backend
NetworkSettings
Network configuration for the stack.
ObservedHealth
ObservedHealth
Platform
Represents the target cloud platform.
PresignedOperation
The type of operation a presigned request performs
PresignedRequestBackend
Storage backend representation for different presigned request types
ProviderLifecycleState
ProviderLifecycleState
QueueHeartbeatData
QueueHeartbeatData
QueueHeartbeatDataVariant0Backend
QueueHeartbeatDataVariant0Backend
QueueHeartbeatDataVariant1Backend
QueueHeartbeatDataVariant1Backend
QueueHeartbeatDataVariant2Backend
QueueHeartbeatDataVariant2Backend
QueueHeartbeatDataVariant3Backend
QueueHeartbeatDataVariant3Backend
RawHeartbeatSnippetFormat
RawHeartbeatSnippetFormat
RemoteStackManagementHeartbeatData
RemoteStackManagementHeartbeatData
RemoteStackManagementHeartbeatDataVariant0Backend
RemoteStackManagementHeartbeatDataVariant0Backend
RemoteStackManagementHeartbeatDataVariant1Backend
RemoteStackManagementHeartbeatDataVariant1Backend
RemoteStackManagementHeartbeatDataVariant2Backend
RemoteStackManagementHeartbeatDataVariant2Backend
ResourceHeartbeatData
ResourceHeartbeatData
ResourceLifecycle
Describes the lifecycle of a resource within a stack, determining how it’s managed and deployed.
ResourceStatus
Represents the high-level status of a resource during its lifecycle.
ServiceAccountHeartbeatData
ServiceAccountHeartbeatData
ServiceAccountHeartbeatDataVariant0Backend
ServiceAccountHeartbeatDataVariant0Backend
ServiceAccountHeartbeatDataVariant1Backend
ServiceAccountHeartbeatDataVariant1Backend
ServiceAccountHeartbeatDataVariant2Backend
ServiceAccountHeartbeatDataVariant2Backend
ServiceAccountHeartbeatDataVariant3Backend
ServiceAccountHeartbeatDataVariant3Backend
ServiceActivationHeartbeatData
ServiceActivationHeartbeatData
ServiceActivationHeartbeatDataVariant0Backend
ServiceActivationHeartbeatDataVariant0Backend
ServiceActivationHeartbeatDataVariant1Backend
ServiceActivationHeartbeatDataVariant1Backend
StorageHeartbeatData
StorageHeartbeatData
StorageHeartbeatDataVariant0Backend
StorageHeartbeatDataVariant0Backend
StorageHeartbeatDataVariant1Backend
StorageHeartbeatDataVariant1Backend
StorageHeartbeatDataVariant2Backend
StorageHeartbeatDataVariant2Backend
StorageHeartbeatDataVariant3Backend
StorageHeartbeatDataVariant3Backend
TelemetryMode
How telemetry (logs, metrics, traces) is handled.
UpdatesMode
How updates are delivered to the deployment.
VaultHeartbeatData
VaultHeartbeatData
VaultHeartbeatDataVariant0Backend
VaultHeartbeatDataVariant0Backend
VaultHeartbeatDataVariant1Backend
VaultHeartbeatDataVariant1Backend
VaultHeartbeatDataVariant2Backend
VaultHeartbeatDataVariant2Backend
VaultHeartbeatDataVariant3Backend
VaultHeartbeatDataVariant3Backend
VaultHeartbeatDataVariant4Backend
VaultHeartbeatDataVariant4Backend
WorkerHeartbeatData
WorkerHeartbeatData
WorkerHeartbeatDataVariant0Backend
WorkerHeartbeatDataVariant0Backend
WorkerHeartbeatDataVariant1Backend
WorkerHeartbeatDataVariant1Backend
WorkerHeartbeatDataVariant2Backend
WorkerHeartbeatDataVariant2Backend
WorkerHeartbeatDataVariant3Backend
WorkerHeartbeatDataVariant3Backend
WorkerHeartbeatDataVariant4Backend
WorkerHeartbeatDataVariant4Backend