Types used as operation parameters and responses.
Modules
Structs
- Acquire
Request AcquireRequest- Acquire
Response AcquireResponse- Acquired
Deployment Response AcquiredDeploymentResponse- Agent
Sync Request AgentSyncRequest- Agent
Sync Response AgentSyncResponse- AwsCustom
Certificate Config AwsCustomCertificateConfig- Azure
Custom Certificate Config AzureCustomCertificateConfig- Command
Payload Response - Payload response containing params and response data from KV
- Command
Status Response - Response to status queries
- Commands
Info CommandsInfo- Create
Command Request - Request to create a new command
- Create
Command Response - Response to command creation
- Create
Deployment Group Request CreateDeploymentGroupRequest- Create
Deployment Request CreateDeploymentRequest- Create
Deployment Response CreateDeploymentResponse- Create
Release Request CreateReleaseRequest- Create
Token Response CreateTokenResponse- Custom
Certificate Config - Platform-specific certificate references for custom domains.
- Custom
Domain Config - Custom domain configuration for a single resource.
- Deployment
Group Minimal DeploymentGroupMinimal- Deployment
Group Response DeploymentGroupResponse- Deployment
Info Response DeploymentInfoResponse- Deployment
Response DeploymentResponse- Domain
Settings - Domain configuration for the stack.
- Envelope
- Commands envelope sent to deployments
- Environment
Variable - Environment variable for deployment
- Error
Response - Error response wrapper for API endpoints
- GcpCustom
Certificate Config GcpCustomCertificateConfig- GitMetadata
GitMetadata- GitMetadata
Response GitMetadataResponse- Health
Response HealthResponse- Initialize
Request InitializeRequest- Initialize
Response InitializeResponse- Lease
Info - Lease information
- Lease
Request - Request for acquiring leases
- Lease
Response - Response to lease acquisition
- List
Deployment Groups Response ListDeploymentGroupsResponse- List
Deployments Response ListDeploymentsResponse- Presigned
Request - A presigned request that can be serialized, stored, and executed later. Hides implementation details for different storage backends.
- Reconcile
Request ReconcileRequest- Reconcile
Response ReconcileResponse- Release
Request ReleaseRequest- Release
Response ReleaseResponse- Resolve
Credentials Request ResolveCredentialsRequest- Resolve
Credentials Response ResolveCredentialsResponse- Resource
Entry ResourceEntry- Response
Handling - Response handling configuration for deployments
- Scope
Info ScopeInfo- Stack
ByPlatform - The release API accepts stacks keyed by platform. Only one platform stack needs to be present.
- Stack
Settings - User-customizable deployment settings specified at deploy time.
- Storage
Upload - Storage upload information
- Store
Payload Request - Request to store payload data directly in KV by command_id.
- Submit
Response Request - Request to submit a command response (from deployment)
- Upload
Complete Request - Request to mark upload as complete
- Upload
Complete Response - Response to upload completion
- Whoami
Response WhoamiResponse
Enums
- Body
Spec - Body specification supporting inline and storage modes
- Command
Response - Command response from deployment
- Command
State - Command states in the Commands protocol lifecycle
- Deployment
Model - Deployment model: how updates are delivered to the remote environment.
- Environment
Variable Type - Type of environment variable
- Heartbeats
Mode - How heartbeat health checks are handled.
- Local
Operation - Local filesystem operations
- Network
Settings - Network configuration for the stack.
- Platform
- Represents the target cloud platform.
- Presigned
Operation - The type of operation a presigned request performs
- Presigned
Request Backend - Storage backend representation for different presigned request types
- Telemetry
Mode - How telemetry (logs, metrics, traces) is handled.
- Updates
Mode - How updates are delivered to the deployment.