Module types

Module types 

Types used as operation parameters and responses.

Modules

builder
Types for composing complex structures.
error
Error types.

Structs

AcquireRequest
AcquireRequest
AcquireResponse
AcquireResponse
AcquiredDeploymentResponse
AcquiredDeploymentResponse
AgentSyncRequest
AgentSyncRequest
AgentSyncResponse
AgentSyncResponse
AwsCustomCertificateConfig
AwsCustomCertificateConfig
AzureCustomCertificateConfig
AzureCustomCertificateConfig
CommandPayloadResponse
Payload response containing params and response data from KV
CommandStatusResponse
Response to status queries
CommandsInfo
CommandsInfo
CreateCommandRequest
Request to create a new command
CreateCommandResponse
Response to command creation
CreateDeploymentGroupRequest
CreateDeploymentGroupRequest
CreateDeploymentRequest
CreateDeploymentRequest
CreateDeploymentResponse
CreateDeploymentResponse
CreateReleaseRequest
CreateReleaseRequest
CreateTokenResponse
CreateTokenResponse
CustomCertificateConfig
Platform-specific certificate references for custom domains.
CustomDomainConfig
Custom domain configuration for a single resource.
DeploymentGroupMinimal
DeploymentGroupMinimal
DeploymentGroupResponse
DeploymentGroupResponse
DeploymentInfoResponse
DeploymentInfoResponse
DeploymentResponse
DeploymentResponse
DomainSettings
Domain configuration for the stack.
Envelope
Commands envelope sent to deployments
EnvironmentVariable
Environment variable for deployment
ErrorResponse
Error response wrapper for API endpoints
GcpCustomCertificateConfig
GcpCustomCertificateConfig
GitMetadata
GitMetadata
GitMetadataResponse
GitMetadataResponse
HealthResponse
HealthResponse
InitializeRequest
InitializeRequest
InitializeResponse
InitializeResponse
LeaseInfo
Lease information
LeaseRequest
Request for acquiring leases
LeaseResponse
Response to lease acquisition
ListDeploymentGroupsResponse
ListDeploymentGroupsResponse
ListDeploymentsResponse
ListDeploymentsResponse
PresignedRequest
A presigned request that can be serialized, stored, and executed later. Hides implementation details for different storage backends.
ReconcileRequest
ReconcileRequest
ReconcileResponse
ReconcileResponse
ReleaseRequest
ReleaseRequest
ReleaseResponse
ReleaseResponse
ResolveCredentialsRequest
ResolveCredentialsRequest
ResolveCredentialsResponse
ResolveCredentialsResponse
ResourceEntry
ResourceEntry
ResponseHandling
Response handling configuration for deployments
ScopeInfo
ScopeInfo
StackByPlatform
The release API accepts stacks keyed by platform. Only one platform stack needs to be present.
StackSettings
User-customizable deployment settings specified at deploy time.
StorageUpload
Storage upload information
StorePayloadRequest
Request to store payload data directly in KV by command_id.
SubmitResponseRequest
Request to submit a command response (from deployment)
UploadCompleteRequest
Request to mark upload as complete
UploadCompleteResponse
Response to upload completion
WhoamiResponse
WhoamiResponse

Enums

BodySpec
Body specification supporting inline and storage modes
CommandResponse
Command response from deployment
CommandState
Command states in the Commands protocol lifecycle
DeploymentModel
Deployment model: how updates are delivered to the remote environment.
EnvironmentVariableType
Type of environment variable
HeartbeatsMode
How heartbeat health checks are handled.
LocalOperation
Local filesystem operations
NetworkSettings
Network configuration for the stack.
Platform
Represents the target cloud platform.
PresignedOperation
The type of operation a presigned request performs
PresignedRequestBackend
Storage backend representation for different presigned request types
TelemetryMode
How telemetry (logs, metrics, traces) is handled.
UpdatesMode
How updates are delivered to the deployment.